==> android-sdk-2.4.2-sources.jar: io/adtrace/sdk/ReferrerDetails.java <==
package io.adtrace.sdk;

/**
 * AdTrace android SDK (https://adtrace.io)
 * Created by Nasser Amini (github.com/namini40) on April 2022.
 * Notice: See LICENSE.txt for modification and distribution information
 *                   Copyright © 2022.
 */

public class ReferrerDetails {
    public String installReferrer;                     // The referrer URL of the installed package.
    public long referrerClickTimestampSeconds;         // The client-side timestamp, when the referrer click happened.
    public long installBeginTimestampSeconds;          // The client-side timestamp, when app installation began.
    public long referrerClickTimestampServerSeconds;   // The server-side timestamp, when the referrer click happened.
    public long installBeginTimestampServerSeconds;    // The server-side timestamp, when app installation began.
    public String installVersion;                      // The app's version at the time when the app was first installed.
    public Boolean googlePlayInstant;                  // Indicates whether app's instant experience was launched within the past 7 days.

    public ReferrerDetails(final String installReferrer,
                           final long referrerClickTimestampSeconds,
                           final long installBeginTimestampSeconds,
                           final long referrerClickTimestampServerSeconds,
                           final long installBeginTimestampServerSeconds,
                           final String installVersion,
                           final Boolean googlePlayInstant) {

        this.installReferrer = installReferrer;
        this.referrerClickTimestampSeconds = referrerClickTimestampSeconds;
        this.installBeginTimestampSeconds = installBeginTimestampSeconds;
        this.referrerClickTimestampServerSeconds = referrerClickTimestampServerSeconds;
        this.installBeginTimestampServerSeconds = installBeginTimestampServerSeconds;
        this.installVersion = installVersion;
        this.googlePlayInstant = googlePlayInstant;
    }

    public ReferrerDetails(final String installReferrer,
                           final long referrerClickTimestampSeconds,
                           final long installBeginTimestampSeconds) {

        this(installReferrer,
                referrerClickTimestampSeconds,
                installBeginTimestampSeconds,
                -1,
                -1,
                null,
                null);

    }

}

==> android-sdk-2.6.0-sources.jar: io/adtrace/sdk/ReferrerDetails.java <==
package io.adtrace.sdk;

/**
 * AdTrace android SDK (https://adtrace.io)
 * Created by Nasser Amini (github.com/namini40) on April 2022.
 * Notice: See LICENSE.txt for modification and distribution information
 *                   Copyright © 2022.
 */

public class ReferrerDetails {
    public String installReferrer;                     // The referrer URL of the installed package.
    public long referrerClickTimestampSeconds;         // The client-side timestamp, when the referrer click happened.
    public long installBeginTimestampSeconds;          // The client-side timestamp, when app installation began.
    public long referrerClickTimestampServerSeconds;   // The server-side timestamp, when the referrer click happened.
    public long installBeginTimestampServerSeconds;    // The server-side timestamp, when app installation began.
    public String installVersion;                      // The app's version at the time when the app was first installed.
    public Boolean googlePlayInstant;                  // Indicates whether app's instant experience was launched within the past 7 days.
    public Boolean isClick;                            // Indicates click (true) or impression (false)

    public ReferrerDetails(final String installReferrer,
                           final long referrerClickTimestampSeconds,
                           final long installBeginTimestampSeconds,
                           final long referrerClickTimestampServerSeconds,
                           final long installBeginTimestampServerSeconds,
                           final String installVersion,
                           final Boolean googlePlayInstant,
                           final Boolean isClick) {

        this.installReferrer = installReferrer;
        this.referrerClickTimestampSeconds = referrerClickTimestampSeconds;
        this.installBeginTimestampSeconds = installBeginTimestampSeconds;
        this.referrerClickTimestampServerSeconds = referrerClickTimestampServerSeconds;
        this.installBeginTimestampServerSeconds = installBeginTimestampServerSeconds;
        this.installVersion = installVersion;
        this.googlePlayInstant = googlePlayInstant;
        this.isClick = isClick;
    }

    public ReferrerDetails(final String installReferrer,
                           final long referrerClickTimestampSeconds,
                           final long installBeginTimestampSeconds) {

        this(installReferrer,
                referrerClickTimestampSeconds,
                installBeginTimestampSeconds,
                -1,
                -1,
                null,
                null,
                null);

    }

    public ReferrerDetails(final String installReferrer,
                           final long referrerClickTimestampSeconds,
                           final Boolean isClick) {

        this(installReferrer,
                referrerClickTimestampSeconds,
                -1,
                -1,
                -1,
                null,
                null,
                isClick);

    }
}
